#include "defines.h"
#include "../include/moves.h"
#include "../include/items.h"
#include "../include/evolution.h"
#include "../include/base_stats.h"

#define TIME_RANGE(startTime, endTime) ((startTime << 8) | endTime)

#define MAPSEC_POWER_PLANT 0x8E
#define MAPSEC_ICEFALL_CAVE 0xB1

const struct Evolution gEvolutionTable[NUM_SPECIES][EVOS_PER_MON] =
{
	[SPECIES_BULBASAUR] =        {{EVO_LEVEL, 16, SPECIES_IVYSAUR, 0}},
	[SPECIES_IVYSAUR] =          {{EVO_LEVEL, 32, SPECIES_VENUSAUR, 0}},
	[SPECIES_VENUSAUR] =         {{EVO_MEGA, ITEM_VENUSAURITE, SPECIES_VENUSAUR_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_CHARMANDER] =       {{EVO_LEVEL, 16, SPECIES_CHARMELEON, 0}},
	[SPECIES_CHARMELEON] =       {{EVO_LEVEL, 36, SPECIES_CHARIZARD, 0}},
	[SPECIES_CHARIZARD] =        {{EVO_MEGA, ITEM_CHARIZARDITE_X, SPECIES_CHARIZARD_MEGA_X, MEGA_VARIANT_STANDARD},
								  {EVO_MEGA, ITEM_CHARIZARDITE_Y, SPECIES_CHARIZARD_MEGA_Y, MEGA_VARIANT_STANDARD}},
	[SPECIES_SQUIRTLE] =         {{EVO_LEVEL, 16, SPECIES_WARTORTLE, 0}},
	[SPECIES_WARTORTLE] =        {{EVO_LEVEL, 36, SPECIES_BLASTOISE, 0}},
	[SPECIES_BLASTOISE] =        {{EVO_MEGA, ITEM_BLASTOISINITE, SPECIES_BLASTOISE_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_CATERPIE] =         {{EVO_LEVEL, 7, SPECIES_METAPOD, 0}},
	[SPECIES_METAPOD] =          {{EVO_LEVEL, 10, SPECIES_BUTTERFREE, 0}},
	[SPECIES_WEEDLE] =           {{EVO_LEVEL, 7, SPECIES_KAKUNA, 0}},
	[SPECIES_KAKUNA] =           {{EVO_LEVEL, 10, SPECIES_BEEDRILL, 0}},
	[SPECIES_BEEDRILL] =         {{EVO_MEGA, ITEM_BEEDRILLITE, SPECIES_BEEDRILL_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_PIDGEY] =           {{EVO_LEVEL, 18, SPECIES_PIDGEOTTO, 0}},
	[SPECIES_PIDGEOTTO] =        {{EVO_LEVEL, 36, SPECIES_PIDGEOT, 0}},
	[SPECIES_PIDGEOT] =          {{EVO_MEGA, ITEM_PIDGEOTITE, SPECIES_PIDGEOT_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_RATTATA] =          {{EVO_LEVEL, 20, SPECIES_RATICATE, 0}},
	[SPECIES_SPEAROW] =          {{EVO_LEVEL, 20, SPECIES_FEAROW, 0}},
	[SPECIES_EKANS] =            {{EVO_LEVEL, 22, SPECIES_ARBOK, 0}},
	[SPECIES_PIKACHU] =          {{EVO_ITEM, ITEM_THUNDER_STONE, SPECIES_RAICHU, 0}},
	[SPECIES_SANDSHREW] =        {{EVO_LEVEL, 22, SPECIES_SANDSLASH, 0}},
	[SPECIES_NIDORAN_F] =        {{EVO_LEVEL, 16, SPECIES_NIDORINA, 0}},
	[SPECIES_NIDORINA] =         {{EVO_ITEM, ITEM_MOON_STONE, SPECIES_NIDOQUEEN, 0}},
	[SPECIES_NIDORAN_M] =        {{EVO_LEVEL, 16, SPECIES_NIDORINO, 0}},
	[SPECIES_NIDORINO] =         {{EVO_ITEM, ITEM_MOON_STONE, SPECIES_NIDOKING, 0}},
	[SPECIES_CLEFAIRY] =         {{EVO_ITEM, ITEM_MOON_STONE, SPECIES_CLEFABLE, 0}},
	[SPECIES_VULPIX] =           {{EVO_ITEM, ITEM_FIRE_STONE, SPECIES_NINETALES, 0}},
	[SPECIES_JIGGLYPUFF] =       {{EVO_ITEM, ITEM_MOON_STONE, SPECIES_WIGGLYTUFF, 0}},
	[SPECIES_ZUBAT] =            {{EVO_LEVEL, 22, SPECIES_GOLBAT, 0}},
	[SPECIES_GOLBAT] =           {{EVO_FRIENDSHIP, 0, SPECIES_CROBAT, 0}},
	[SPECIES_ODDISH] =           {{EVO_LEVEL, 21, SPECIES_GLOOM, 0}},
	[SPECIES_GLOOM] =            {{EVO_ITEM, ITEM_SUN_STONE, SPECIES_BELLOSSOM, 0},
								  {EVO_ITEM, ITEM_LEAF_STONE, SPECIES_VILEPLUME, 0}},
	[SPECIES_PARAS] =            {{EVO_LEVEL, 24, SPECIES_PARASECT, 0}},
	[SPECIES_VENONAT] =          {{EVO_LEVEL, 31, SPECIES_VENOMOTH, 0}},
	[SPECIES_DIGLETT] =          {{EVO_LEVEL, 26, SPECIES_DUGTRIO, 0}},
	[SPECIES_MEOWTH] =           {{EVO_LEVEL, 28, SPECIES_PERSIAN, 0}},
	[SPECIES_PSYDUCK] =          {{EVO_LEVEL, 33, SPECIES_GOLDUCK, 0}},
	[SPECIES_MANKEY] =           {{EVO_LEVEL, 28, SPECIES_PRIMEAPE, 0}},
	[SPECIES_GROWLITHE] =        {{EVO_ITEM, ITEM_FIRE_STONE, SPECIES_ARCANINE, 0}},
	[SPECIES_POLIWAG] =          {{EVO_LEVEL, 25, SPECIES_POLIWHIRL, 0}},
	[SPECIES_POLIWHIRL] =        {{EVO_ITEM, ITEM_WATER_STONE, SPECIES_POLIWRATH, 0},
								  {EVO_TRADE_ITEM, ITEM_KINGS_ROCK, SPECIES_POLITOED, 0},
								  {EVO_ITEM, ITEM_KINGS_ROCK, SPECIES_POLITOED, 0}},
	[SPECIES_ABRA] =             {{EVO_LEVEL, 16, SPECIES_KADABRA, 0}},
	[SPECIES_KADABRA] =          {{EVO_TRADE, 0, SPECIES_ALAKAZAM, 0},
								  {EVO_ITEM, ITEM_LINK_CABLE, SPECIES_ALAKAZAM, 0}},
	[SPECIES_ALAKAZAM] =         {{EVO_MEGA, ITEM_ALAKAZITE, SPECIES_ALAKAZAM_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_MACHOP] =           {{EVO_LEVEL, 28, SPECIES_MACHOKE, 0}},
	[SPECIES_MACHOKE] =          {{EVO_TRADE, 0, SPECIES_MACHAMP, 0},
								  {EVO_ITEM, ITEM_LINK_CABLE, SPECIES_MACHAMP, 0}},
	[SPECIES_BELLSPROUT] =       {{EVO_LEVEL, 21, SPECIES_WEEPINBELL, 0}},
	[SPECIES_WEEPINBELL] =       {{EVO_ITEM, ITEM_LEAF_STONE, SPECIES_VICTREEBEL, 0}},
	[SPECIES_TENTACOOL] =        {{EVO_LEVEL, 30, SPECIES_TENTACRUEL, 0}},
	[SPECIES_GEODUDE] =          {{EVO_LEVEL, 25, SPECIES_GRAVELER, 0}},
	[SPECIES_GRAVELER] =         {{EVO_ITEM, ITEM_LINK_CABLE, SPECIES_GOLEM, 0},
								  {EVO_TRADE, 0, SPECIES_GOLEM, 0}},
	[SPECIES_PONYTA] =           {{EVO_LEVEL, 40, SPECIES_RAPIDASH, 0}},
	[SPECIES_SLOWPOKE] =         {{EVO_LEVEL, 37, SPECIES_SLOWBRO, 0},
								  {EVO_TRADE_ITEM, ITEM_KINGS_ROCK, SPECIES_SLOWKING, 0},
								  {EVO_ITEM, ITEM_KINGS_ROCK, SPECIES_SLOWKING, 0}},
	[SPECIES_SLOWBRO] =          {{EVO_MEGA, ITEM_SLOWBRONITE, SPECIES_SLOWBRO_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_MAGNEMITE] =        {{EVO_LEVEL, 30, SPECIES_MAGNETON, 0}},
	[SPECIES_MAGNETON] =         {{EVO_ITEM, ITEM_THUNDER_STONE, SPECIES_MAGNEZONE, 0}},
	[SPECIES_DODUO] =            {{EVO_LEVEL, 31, SPECIES_DODRIO, 0}},
	[SPECIES_SEEL] =             {{EVO_LEVEL, 34, SPECIES_DEWGONG, 0}},
	[SPECIES_GRIMER] =           {{EVO_LEVEL, 38, SPECIES_MUK, 0}},
	[SPECIES_SHELLDER] =         {{EVO_ITEM, ITEM_WATER_STONE, SPECIES_CLOYSTER, 0}},
	[SPECIES_GASTLY] =           {{EVO_LEVEL, 25, SPECIES_HAUNTER, 0}},
	[SPECIES_HAUNTER] =          {{EVO_TRADE, 0, SPECIES_GENGAR, 0},
								  {EVO_ITEM, ITEM_LINK_CABLE, SPECIES_GENGAR, 0}},
	[SPECIES_GENGAR] =           {{EVO_MEGA, ITEM_GENGARITE, SPECIES_GENGAR_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_ONIX] =             {{EVO_TRADE_ITEM, ITEM_METAL_COAT, SPECIES_STEELIX, 0},
								  {EVO_ITEM, ITEM_METAL_COAT, SPECIES_STEELIX, 0}},
	[SPECIES_DROWZEE] =          {{EVO_LEVEL, 26, SPECIES_HYPNO, 0}},
	[SPECIES_KRABBY] =           {{EVO_LEVEL, 28, SPECIES_KINGLER, 0}},
	[SPECIES_VOLTORB] =          {{EVO_LEVEL, 30, SPECIES_ELECTRODE, 0}},
	[SPECIES_EXEGGCUTE] =        {{EVO_ITEM, ITEM_LEAF_STONE, SPECIES_EXEGGUTOR, 0}},
	[SPECIES_CUBONE] =           {{EVO_LEVEL, 28, SPECIES_MAROWAK, 0}},
	[SPECIES_LICKITUNG] =        {{EVO_MOVE, MOVE_ROLLOUT, SPECIES_LICKILICKY, 0}},
	[SPECIES_KOFFING] =          {{EVO_LEVEL, 35, SPECIES_WEEZING, 0}},
	[SPECIES_RHYHORN] =          {{EVO_LEVEL, 42, SPECIES_RHYDON, 0}},
	[SPECIES_RHYDON] =           {{EVO_ITEM, ITEM_PROTECTOR, SPECIES_RHYPERIOR, 0},
								  {EVO_TRADE_ITEM, ITEM_PROTECTOR, SPECIES_RHYPERIOR, 0}},
	[SPECIES_CHANSEY] =          {{EVO_FRIENDSHIP, 0, SPECIES_BLISSEY, 0}},
	[SPECIES_TANGELA] =          {{EVO_MOVE, MOVE_ANCIENTPOWER, SPECIES_TANGROWTH, 0}},
	[SPECIES_KANGASKHAN] =       {{EVO_MEGA, ITEM_KANGASKHANITE, SPECIES_KANGASKHAN_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_HORSEA] =           {{EVO_LEVEL, 32, SPECIES_SEADRA, 0}},
	[SPECIES_SEADRA] =           {{EVO_TRADE_ITEM, ITEM_DRAGON_SCALE, SPECIES_KINGDRA, 0},
								  {EVO_ITEM, ITEM_DRAGON_SCALE, SPECIES_KINGDRA, 0}},
	[SPECIES_GOLDEEN] =          {{EVO_LEVEL, 33, SPECIES_SEAKING, 0}},
	[SPECIES_STARYU] =           {{EVO_ITEM, ITEM_WATER_STONE, SPECIES_STARMIE, 0}},
	[SPECIES_SCYTHER] =          {{EVO_TRADE_ITEM, ITEM_METAL_COAT, SPECIES_SCIZOR, 0},
								  {EVO_ITEM, ITEM_METAL_COAT, SPECIES_SCIZOR, 0}},
	[SPECIES_ELECTABUZZ] =       {{EVO_ITEM, ITEM_ELECTIRIZER, SPECIES_ELECTIVIRE, 0},
								  {EVO_TRADE_ITEM, ITEM_ELECTIRIZER, SPECIES_ELECTIVIRE, 0}},
	[SPECIES_MAGMAR] =           {{EVO_TRADE_ITEM, ITEM_MAGMARIZER, SPECIES_MAGMORTAR, 0},
								  {EVO_ITEM, ITEM_MAGMARIZER, SPECIES_MAGMORTAR, 0}},
	[SPECIES_PINSIR] =           {{EVO_MEGA, ITEM_PINSIRITE, SPECIES_PINSIR_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_MAGIKARP] =         {{EVO_LEVEL, 20, SPECIES_GYARADOS, 0}},
	[SPECIES_GYARADOS] =         {{EVO_MEGA, ITEM_GYARADOSITE, SPECIES_GYARADOS_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_EEVEE] =            {{EVO_FRIENDSHIP_DAY, 0, SPECIES_ESPEON, 0},
								  {EVO_FRIENDSHIP_NIGHT, 0, SPECIES_UMBREON, 0},
								  {EVO_MOVE_TYPE, TYPE_FAIRY, SPECIES_SYLVEON, TRUE}, //Require high friendship
								  {EVO_ITEM, ITEM_FIRE_STONE, SPECIES_FLAREON, 0},
								  {EVO_ITEM, ITEM_THUNDER_STONE, SPECIES_JOLTEON, 0},
								  {EVO_ITEM, ITEM_WATER_STONE, SPECIES_VAPOREON, 0},
								  {EVO_ITEM, ITEM_LEAF_STONE, SPECIES_LEAFEON, 0},
								  {EVO_ITEM, ITEM_ICE_STONE, SPECIES_GLACEON, 0}},
	[SPECIES_PORYGON] =          {{EVO_ITEM, ITEM_UP_GRADE, SPECIES_PORYGON2, 0},
								  {EVO_TRADE_ITEM, ITEM_UP_GRADE, SPECIES_PORYGON2, 0}},
	[SPECIES_OMANYTE] =          {{EVO_LEVEL, 40, SPECIES_OMASTAR, 0}},
	[SPECIES_KABUTO] =           {{EVO_LEVEL, 40, SPECIES_KABUTOPS, 0}},
	[SPECIES_AERODACTYL] =       {{EVO_MEGA, ITEM_AERODACTYLITE, SPECIES_AERODACTYL_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_DRATINI] =          {{EVO_LEVEL, 30, SPECIES_DRAGONAIR, 0}},
	[SPECIES_DRAGONAIR] =        {{EVO_LEVEL, 55, SPECIES_DRAGONITE, 0}},
	[SPECIES_MEWTWO] =           {{EVO_MEGA, ITEM_MEWTWONITE_X, SPECIES_MEWTWO_MEGA_X, MEGA_VARIANT_STANDARD},
								  {EVO_MEGA, ITEM_MEWTWONITE_Y, SPECIES_MEWTWO_MEGA_Y, MEGA_VARIANT_STANDARD}},
	[SPECIES_CHIKORITA] =        {{EVO_LEVEL, 16, SPECIES_BAYLEEF, 0}},
	[SPECIES_BAYLEEF] =          {{EVO_LEVEL, 32, SPECIES_MEGANIUM, 0}},
	[SPECIES_CYNDAQUIL] =        {{EVO_LEVEL, 14, SPECIES_QUILAVA, 0}},
	[SPECIES_QUILAVA] =          {{EVO_LEVEL, 36, SPECIES_TYPHLOSION, 0}},
	[SPECIES_TOTODILE] =         {{EVO_LEVEL, 18, SPECIES_CROCONAW, 0}},
	[SPECIES_CROCONAW] =         {{EVO_LEVEL, 30, SPECIES_FERALIGATR, 0}},
	[SPECIES_SENTRET] =          {{EVO_LEVEL, 15, SPECIES_FURRET, 0}},
	[SPECIES_HOOTHOOT] =         {{EVO_LEVEL, 20, SPECIES_NOCTOWL, 0}},
	[SPECIES_LEDYBA] =           {{EVO_LEVEL, 18, SPECIES_LEDIAN, 0}},
	[SPECIES_SPINARAK] =         {{EVO_LEVEL, 22, SPECIES_ARIADOS, 0}},
	[SPECIES_CHINCHOU] =         {{EVO_LEVEL, 27, SPECIES_LANTURN, 0}},
	[SPECIES_PICHU] =            {{EVO_FRIENDSHIP, 0, SPECIES_PIKACHU, 0}},
	[SPECIES_CLEFFA] =           {{EVO_FRIENDSHIP, 0, SPECIES_CLEFAIRY, 0}},
	[SPECIES_IGGLYBUFF] =        {{EVO_FRIENDSHIP, 0, SPECIES_JIGGLYPUFF, 0}},
	[SPECIES_TOGEPI] =           {{EVO_FRIENDSHIP, 0, SPECIES_TOGETIC, 0}},
	[SPECIES_TOGETIC] =          {{EVO_ITEM, ITEM_SHINY_STONE, SPECIES_TOGEKISS, 0}},
	[SPECIES_NATU] =             {{EVO_LEVEL, 25, SPECIES_XATU, 0}},
	[SPECIES_MAREEP] =           {{EVO_LEVEL, 15, SPECIES_FLAAFFY, 0}},
	[SPECIES_FLAAFFY] =          {{EVO_LEVEL, 30, SPECIES_AMPHAROS, 0}},
	[SPECIES_AMPHAROS] =         {{EVO_MEGA, ITEM_AMPHAROSITE, SPECIES_AMPHAROS_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_MARILL] =           {{EVO_LEVEL, 18, SPECIES_AZUMARILL, 0}},
	[SPECIES_HOPPIP] =           {{EVO_LEVEL, 18, SPECIES_SKIPLOOM, 0}},
	[SPECIES_SKIPLOOM] =         {{EVO_LEVEL, 27, SPECIES_JUMPLUFF, 0}},
	[SPECIES_AIPOM] =            {{EVO_MOVE, MOVE_DOUBLEHIT, SPECIES_AMBIPOM, 0}},
	[SPECIES_SUNKERN] =          {{EVO_ITEM, ITEM_SUN_STONE, SPECIES_SUNFLORA, 0}},
	[SPECIES_YANMA] =            {{EVO_MOVE, MOVE_ANCIENTPOWER, SPECIES_YANMEGA, 0}},
	[SPECIES_WOOPER] =           {{EVO_LEVEL, 20, SPECIES_QUAGSIRE, 0}},
	[SPECIES_MURKROW] =          {{EVO_ITEM, ITEM_DUSK_STONE, SPECIES_HONCHKROW, 0}},
	[SPECIES_MISDREAVUS] =       {{EVO_ITEM, ITEM_DUSK_STONE, SPECIES_MISMAGIUS, 0}},
	[SPECIES_PINECO] =           {{EVO_LEVEL, 31, SPECIES_FORRETRESS, 0}},
	[SPECIES_GLIGAR] =           {{EVO_HOLD_ITEM_NIGHT, ITEM_RAZOR_FANG, SPECIES_GLISCOR, 0}},
	[SPECIES_STEELIX] =          {{EVO_MEGA, ITEM_STEELIXITE, SPECIES_STEELIX_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_SNUBBULL] =         {{EVO_LEVEL, 23, SPECIES_GRANBULL, 0}},
	[SPECIES_SCIZOR] =           {{EVO_MEGA, ITEM_SCIZORITE, SPECIES_SCIZOR_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_HERACROSS] =        {{EVO_MEGA, ITEM_HERACRONITE, SPECIES_HERACROSS_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_SNEASEL] =          {{EVO_HOLD_ITEM_NIGHT, ITEM_RAZOR_CLAW, SPECIES_WEAVILE, 0}},
	[SPECIES_TEDDIURSA] =        {{EVO_LEVEL, 30, SPECIES_URSARING, 0}},
	[SPECIES_SLUGMA] =           {{EVO_LEVEL, 38, SPECIES_MAGCARGO, 0}},
	[SPECIES_SWINUB] =           {{EVO_LEVEL, 33, SPECIES_PILOSWINE, 0}},
	[SPECIES_PILOSWINE] =        {{EVO_MOVE, MOVE_ANCIENTPOWER, SPECIES_MAMOSWINE, 0}},
	[SPECIES_REMORAID] =         {{EVO_LEVEL, 25, SPECIES_OCTILLERY, 0}},
	[SPECIES_HOUNDOUR] =         {{EVO_LEVEL, 24, SPECIES_HOUNDOOM, 0}},
	[SPECIES_HOUNDOOM] =         {{EVO_MEGA, ITEM_HOUNDOOMINITE, SPECIES_HOUNDOOM_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_PHANPY] =           {{EVO_LEVEL, 25, SPECIES_DONPHAN, 0}},
	[SPECIES_PORYGON2] =         {{EVO_TRADE_ITEM, ITEM_DUBIOUS_DISC, SPECIES_PORYGON_Z, 0},
								  {EVO_ITEM, ITEM_DUBIOUS_DISC, SPECIES_PORYGON_Z, 0}},
	[SPECIES_TYROGUE] =          {{EVO_LEVEL_ATK_GT_DEF, 20, SPECIES_HITMONLEE, 0},
								  {EVO_LEVEL_ATK_EQ_DEF, 20, SPECIES_HITMONTOP, 0},
								  {EVO_LEVEL_ATK_LT_DEF, 20, SPECIES_HITMONCHAN, 0}},
	[SPECIES_SMOOCHUM] =         {{EVO_LEVEL, 30, SPECIES_JYNX, 0}},
	[SPECIES_ELEKID] =           {{EVO_LEVEL, 30, SPECIES_ELECTABUZZ, 0}},
	[SPECIES_MAGBY] =            {{EVO_LEVEL, 30, SPECIES_MAGMAR, 0}},
	[SPECIES_LARVITAR] =         {{EVO_LEVEL, 30, SPECIES_PUPITAR, 0}},
	[SPECIES_PUPITAR] =          {{EVO_LEVEL, 55, SPECIES_TYRANITAR, 0}},
	[SPECIES_TYRANITAR] =        {{EVO_MEGA, ITEM_TYRANITARITE, SPECIES_TYRANITAR_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_TREECKO] =          {{EVO_LEVEL, 16, SPECIES_GROVYLE, 0}},
	[SPECIES_GROVYLE] =          {{EVO_LEVEL, 36, SPECIES_SCEPTILE, 0}},
	[SPECIES_SCEPTILE] =         {{EVO_MEGA, ITEM_SCEPTILITE, SPECIES_SCEPTILE_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_TORCHIC] =          {{EVO_LEVEL, 16, SPECIES_COMBUSKEN, 0}},
	[SPECIES_COMBUSKEN] =        {{EVO_LEVEL, 36, SPECIES_BLAZIKEN, 0}},
	[SPECIES_BLAZIKEN] =         {{EVO_MEGA, ITEM_BLAZIKENITE, SPECIES_BLAZIKEN_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_MUDKIP] =           {{EVO_LEVEL, 16, SPECIES_MARSHTOMP, 0}},
	[SPECIES_MARSHTOMP] =        {{EVO_LEVEL, 36, SPECIES_SWAMPERT, 0}},
	[SPECIES_SWAMPERT] =         {{EVO_MEGA, ITEM_SWAMPERTITE, SPECIES_SWAMPERT_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_POOCHYENA] =        {{EVO_LEVEL, 18, SPECIES_MIGHTYENA, 0}},
	[SPECIES_ZIGZAGOON] =        {{EVO_LEVEL, 20, SPECIES_LINOONE, 0}},
	[SPECIES_WURMPLE] =          {{EVO_LEVEL_SILCOON, 7, SPECIES_SILCOON, 0},
								  {EVO_LEVEL_CASCOON, 7, SPECIES_CASCOON, 0}},
	[SPECIES_SILCOON] =          {{EVO_LEVEL, 10, SPECIES_BEAUTIFLY, 0}},
	[SPECIES_CASCOON] =          {{EVO_LEVEL, 10, SPECIES_DUSTOX, 0}},
	[SPECIES_LOTAD] =            {{EVO_LEVEL, 14, SPECIES_LOMBRE, 0}},
	[SPECIES_LOMBRE] =           {{EVO_ITEM, ITEM_WATER_STONE, SPECIES_LUDICOLO, 0}},
	[SPECIES_SEEDOT] =           {{EVO_LEVEL, 14, SPECIES_NUZLEAF, 0}},
	[SPECIES_NUZLEAF] =          {{EVO_ITEM, ITEM_LEAF_STONE, SPECIES_SHIFTRY, 0}},
	[SPECIES_NINCADA] =          {{EVO_LEVEL_NINJASK, 20, SPECIES_NINJASK, 0},
								  {EVO_LEVEL_SHEDINJA, 20, SPECIES_SHEDINJA, 0}},
	[SPECIES_TAILLOW] =          {{EVO_LEVEL, 22, SPECIES_SWELLOW, 0}},
	[SPECIES_SHROOMISH] =        {{EVO_LEVEL, 23, SPECIES_BRELOOM, 0}},
	[SPECIES_WINGULL] =          {{EVO_LEVEL, 25, SPECIES_PELIPPER, 0}},
	[SPECIES_SURSKIT] =          {{EVO_LEVEL, 22, SPECIES_MASQUERAIN, 0}},
	[SPECIES_WAILMER] =          {{EVO_LEVEL, 40, SPECIES_WAILORD, 0}},
	[SPECIES_SKITTY] =           {{EVO_ITEM, ITEM_MOON_STONE, SPECIES_DELCATTY, 0}},
	[SPECIES_BALTOY] =           {{EVO_LEVEL, 36, SPECIES_CLAYDOL, 0}},
	[SPECIES_NOSEPASS] =         {{EVO_ITEM, ITEM_THUNDER_STONE, SPECIES_PROBOPASS, 0}},
	[SPECIES_SABLEYE] =          {{EVO_MEGA, ITEM_SABLENITE, SPECIES_SABLEYE_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_BARBOACH] =         {{EVO_LEVEL, 30, SPECIES_WHISCASH, 0}},
	[SPECIES_CORPHISH] =         {{EVO_LEVEL, 30, SPECIES_CRAWDAUNT, 0}},
	[SPECIES_FEEBAS] =           {{EVO_ITEM, ITEM_PRISM_SCALE, SPECIES_MILOTIC, 0},
						{EVO_TRADE_ITEM, ITEM_PRISM_SCALE, SPECIES_MILOTIC, 0}},
	[SPECIES_CARVANHA] =         {{EVO_LEVEL, 30, SPECIES_SHARPEDO, 0}},
	[SPECIES_SHARPEDO] =         {{EVO_MEGA, ITEM_SHARPEDONITE, SPECIES_SHARPEDO_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_TRAPINCH] =         {{EVO_LEVEL, 35, SPECIES_VIBRAVA, 0}},
	[SPECIES_VIBRAVA] =          {{EVO_LEVEL, 45, SPECIES_FLYGON, 0}},
	[SPECIES_MAKUHITA] =         {{EVO_LEVEL, 24, SPECIES_HARIYAMA, 0}},
	[SPECIES_ELECTRIKE] =        {{EVO_LEVEL, 26, SPECIES_MANECTRIC, 0}},
	[SPECIES_MANECTRIC] =        {{EVO_MEGA, ITEM_MANECTITE, SPECIES_MANECTRIC_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_NUMEL] =            {{EVO_LEVEL, 33, SPECIES_CAMERUPT, 0}},
	[SPECIES_CAMERUPT] =         {{EVO_MEGA, ITEM_CAMERUPTITE, SPECIES_CAMERUPT_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_SPHEAL] =           {{EVO_LEVEL, 32, SPECIES_SEALEO, 0}},
	[SPECIES_SEALEO] =           {{EVO_LEVEL, 44, SPECIES_WALREIN, 0}},
	[SPECIES_CACNEA] =           {{EVO_LEVEL, 32, SPECIES_CACTURNE, 0}},
	[SPECIES_SNORUNT] =          {{EVO_LEVEL, 42, SPECIES_GLALIE, 0},
								  {EVO_ITEM, ITEM_DAWN_STONE, SPECIES_FROSLASS, MON_FEMALE}},
	[SPECIES_GLALIE] =           {{EVO_MEGA, ITEM_GLALITITE, SPECIES_GLALIE_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_AZURILL] =          {{EVO_FRIENDSHIP, 0, SPECIES_MARILL, 0}},
	[SPECIES_SPOINK] =           {{EVO_LEVEL, 32, SPECIES_GRUMPIG, 0}},
	[SPECIES_MAWILE] =           {{EVO_MEGA, ITEM_MAWILITE, SPECIES_MAWILE_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_MEDITITE] =         {{EVO_LEVEL, 37, SPECIES_MEDICHAM, 0}},
	[SPECIES_MEDICHAM] =         {{EVO_MEGA, ITEM_MEDICHAMITE, SPECIES_MEDICHAM_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_SWABLU] =           {{EVO_LEVEL, 35, SPECIES_ALTARIA, 0}},
	[SPECIES_ALTARIA] =          {{EVO_MEGA, ITEM_ALTARIANITE, SPECIES_ALTARIA_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_WYNAUT] =           {{EVO_LEVEL, 15, SPECIES_WOBBUFFET, 0}},
	[SPECIES_DUSKULL] =          {{EVO_LEVEL, 37, SPECIES_DUSCLOPS, 0}},
	[SPECIES_DUSCLOPS] =         {{EVO_ITEM, ITEM_REAPER_CLOTH, SPECIES_DUSKNOIR, 0},
								  {EVO_TRADE_ITEM, ITEM_REAPER_CLOTH, SPECIES_DUSKNOIR, 0}},
	[SPECIES_ROSELIA] =          {{EVO_ITEM, ITEM_SHINY_STONE, SPECIES_ROSERADE, 0}},
	[SPECIES_SLAKOTH] =          {{EVO_LEVEL, 18, SPECIES_VIGOROTH, 0}},
	[SPECIES_VIGOROTH] =         {{EVO_LEVEL, 36, SPECIES_SLAKING, 0}},
	[SPECIES_GULPIN] =           {{EVO_LEVEL, 26, SPECIES_SWALOT, 0}},
	[SPECIES_WHISMUR] =          {{EVO_LEVEL, 20, SPECIES_LOUDRED, 0}},
	[SPECIES_LOUDRED] =          {{EVO_LEVEL, 40, SPECIES_EXPLOUD, 0}},
	[SPECIES_CLAMPERL] =         {{EVO_ITEM, ITEM_DEEP_SEA_TOOTH, SPECIES_HUNTAIL, 0},
								  {EVO_ITEM, ITEM_DEEP_SEA_SCALE, SPECIES_GOREBYSS, 0},
								  {EVO_TRADE_ITEM, ITEM_DEEP_SEA_TOOTH, SPECIES_HUNTAIL, 0},
								  {EVO_TRADE_ITEM, ITEM_DEEP_SEA_SCALE, SPECIES_GOREBYSS, 0}},
	[SPECIES_ABSOL] =            {{EVO_MEGA, ITEM_ABSOLITE, SPECIES_ABSOL_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_SHUPPET] =          {{EVO_LEVEL, 37, SPECIES_BANETTE, 0}},
	[SPECIES_BANETTE] =          {{EVO_MEGA, ITEM_BANETTITE, SPECIES_BANETTE_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_ARON] =             {{EVO_LEVEL, 32, SPECIES_LAIRON, 0}},
	[SPECIES_LAIRON] =           {{EVO_LEVEL, 42, SPECIES_AGGRON, 0}},
	[SPECIES_AGGRON] =           {{EVO_MEGA, ITEM_AGGRONITE, SPECIES_AGGRON_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_LILEEP] =           {{EVO_LEVEL, 40, SPECIES_CRADILY, 0}},
	[SPECIES_ANORITH] =          {{EVO_LEVEL, 40, SPECIES_ARMALDO, 0}},
	[SPECIES_RALTS] =            {{EVO_LEVEL, 20, SPECIES_KIRLIA, 0}},
	[SPECIES_KIRLIA] =           {{EVO_LEVEL, 30, SPECIES_GARDEVOIR, 0},
								  {EVO_ITEM, ITEM_DAWN_STONE, SPECIES_GALLADE, MON_MALE}},
	[SPECIES_GARDEVOIR] =        {{EVO_MEGA, ITEM_GARDEVOIRITE, SPECIES_GARDEVOIR_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_BAGON] =            {{EVO_LEVEL, 30, SPECIES_SHELGON, 0}},
	[SPECIES_SHELGON] =          {{EVO_LEVEL, 50, SPECIES_SALAMENCE, 0}},
	[SPECIES_SALAMENCE] =        {{EVO_MEGA, ITEM_SALAMENCITE, SPECIES_SALAMENCE_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_BELDUM] =           {{EVO_LEVEL, 20, SPECIES_METANG, 0}},
	[SPECIES_METANG] =           {{EVO_LEVEL, 45, SPECIES_METAGROSS, 0}},
	[SPECIES_METAGROSS] =        {{EVO_MEGA, ITEM_METAGROSSITE, SPECIES_METAGROSS_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_KYOGRE] =           {{EVO_MEGA, ITEM_BLUE_ORB, SPECIES_KYOGRE_PRIMAL, MEGA_VARIANT_PRIMAL}},
	[SPECIES_GROUDON] =          {{EVO_MEGA, ITEM_RED_ORB, SPECIES_GROUDON_PRIMAL, MEGA_VARIANT_PRIMAL}},
	[SPECIES_RAYQUAZA] =         {{EVO_MEGA, MOVE_DRAGONASCENT, SPECIES_RAYQUAZA_MEGA, MEGA_VARIANT_WISH}},
	[SPECIES_LATIAS] =           {{EVO_MEGA, ITEM_LATIASITE, SPECIES_LATIAS_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_LATIOS] =           {{EVO_MEGA, ITEM_LATIOSITE, SPECIES_LATIOS_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_TURTWIG] =          {{EVO_LEVEL, 18, SPECIES_GROTLE, 0}},
	[SPECIES_GROTLE] =           {{EVO_LEVEL, 32, SPECIES_TORTERRA, 0}},
	[SPECIES_CHIMCHAR] =         {{EVO_LEVEL, 14, SPECIES_MONFERNO, 0}},
	[SPECIES_MONFERNO] =         {{EVO_LEVEL, 36, SPECIES_INFERNAPE, 0}},
	[SPECIES_PIPLUP] =           {{EVO_LEVEL, 16, SPECIES_PRINPLUP, 0}},
	[SPECIES_PRINPLUP] =         {{EVO_LEVEL, 36, SPECIES_EMPOLEON, 0}},
	[SPECIES_STARLY] =           {{EVO_LEVEL, 14, SPECIES_STARAVIA, 0}},
	[SPECIES_STARAVIA] =         {{EVO_LEVEL, 34, SPECIES_STARAPTOR, 0}},
	[SPECIES_BIDOOF] =           {{EVO_LEVEL, 15, SPECIES_BIBAREL, 0}},
	[SPECIES_KRICKETOT] =        {{EVO_LEVEL, 10, SPECIES_KRICKETUNE, 0}},
	[SPECIES_SHINX] =            {{EVO_LEVEL, 15, SPECIES_LUXIO, 0}},
	[SPECIES_LUXIO] =            {{EVO_LEVEL, 30, SPECIES_LUXRAY, 0}},
	[SPECIES_BUDEW] =            {{EVO_FRIENDSHIP_DAY, 0, SPECIES_ROSELIA, 0}},
	[SPECIES_CRANIDOS] =         {{EVO_LEVEL, 30, SPECIES_RAMPARDOS, 0}},
	[SPECIES_SHIELDON] =         {{EVO_LEVEL, 30, SPECIES_BASTIODON, 0}},
	[SPECIES_BURMY] =            {{EVO_FEMALE_LEVEL, 20, SPECIES_WORMADAM, 0},
								  {EVO_MALE_LEVEL, 20, SPECIES_MOTHIM, 0}},
	[SPECIES_COMBEE] =           {{EVO_FEMALE_LEVEL, 21, SPECIES_VESPIQUEN, 0}},
	[SPECIES_BUIZEL] =           {{EVO_LEVEL, 26, SPECIES_FLOATZEL, 0}},
	[SPECIES_CHERUBI] =          {{EVO_LEVEL, 25, SPECIES_CHERRIM, 0}},
	[SPECIES_SHELLOS] =          {{EVO_LEVEL, 30, SPECIES_GASTRODON, 0}},
	[SPECIES_DRIFLOON] =         {{EVO_LEVEL, 28, SPECIES_DRIFBLIM, 0}},
	[SPECIES_BUNEARY] =          {{EVO_FRIENDSHIP, 0, SPECIES_LOPUNNY, 0}},
	[SPECIES_LOPUNNY] =          {{EVO_MEGA, ITEM_LOPUNNITE, SPECIES_LOPUNNY_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_GLAMEOW] =          {{EVO_LEVEL, 38, SPECIES_PURUGLY, 0}},
	[SPECIES_CHINGLING] =        {{EVO_FRIENDSHIP_NIGHT, 0, SPECIES_CHIMECHO, 0}},
	[SPECIES_STUNKY] =           {{EVO_LEVEL, 34, SPECIES_SKUNTANK, 0}},
	[SPECIES_BRONZOR] =          {{EVO_LEVEL, 33, SPECIES_BRONZONG, 0}},
	[SPECIES_BONSLY] =           {{EVO_MOVE, MOVE_MIMIC, SPECIES_SUDOWOODO, 0}},
	[SPECIES_MIME_JR] =          {{EVO_MOVE, MOVE_MIMIC, SPECIES_MR_MIME, 0}},
	[SPECIES_HAPPINY] =          {{EVO_HOLD_ITEM_DAY, ITEM_OVAL_STONE, SPECIES_CHANSEY, 0}},
	[SPECIES_GIBLE] =            {{EVO_LEVEL, 24, SPECIES_GABITE, 0}},
	[SPECIES_GABITE] =           {{EVO_LEVEL, 48, SPECIES_GARCHOMP, 0}},
	[SPECIES_GARCHOMP] =         {{EVO_MEGA, ITEM_GARCHOMPITE, SPECIES_GARCHOMP_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_MUNCHLAX] =         {{EVO_FRIENDSHIP, 0, SPECIES_SNORLAX, 0}},
	[SPECIES_RIOLU] =            {{EVO_FRIENDSHIP_DAY, 0, SPECIES_LUCARIO, 0}},
	[SPECIES_LUCARIO] =          {{EVO_MEGA, ITEM_LUCARIONITE, SPECIES_LUCARIO_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_HIPPOPOTAS] =       {{EVO_LEVEL, 34, SPECIES_HIPPOWDON, 0}},
	[SPECIES_SKORUPI] =          {{EVO_LEVEL, 40, SPECIES_DRAPION, 0}},
	[SPECIES_CROAGUNK] =         {{EVO_LEVEL, 37, SPECIES_TOXICROAK, 0}},
	[SPECIES_FINNEON] =          {{EVO_LEVEL, 31, SPECIES_LUMINEON, 0}},
	[SPECIES_MANTYKE] =          {{EVO_LEVEL, 32, SPECIES_MANTINE, 0}},
	[SPECIES_SNOVER] =           {{EVO_LEVEL, 40, SPECIES_ABOMASNOW, 0}},
	[SPECIES_ABOMASNOW] =        {{EVO_MEGA, ITEM_ABOMASITE, SPECIES_ABOMASNOW_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_GALLADE] =          {{EVO_MEGA, ITEM_GALLADITE, SPECIES_GALLADE_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_ROTOM] =	     {{EVO_ITEM, ITEM_FIRE_STONE, SPECIES_ROTOM_HEAT, 0},
					{EVO_ITEM, ITEM_WATER_STONE, SPECIES_ROTOM_WASH, 0},
					{EVO_ITEM, ITEM_ICE_STONE, SPECIES_ROTOM_FROST, 0},
					{EVO_ITEM, ITEM_LEAF_STONE, SPECIES_ROTOM_MOW, 0},
					{EVO_ITEM, ITEM_SHINY_STONE, SPECIES_ROTOM_FAN, 0}},
	[SPECIES_PHIONE] =           {{EVO_LEVEL, 101, SPECIES_MANAPHY, 0}},
	[SPECIES_SNIVY] =            {{EVO_LEVEL, 17, SPECIES_SERVINE, 0}},
	[SPECIES_SERVINE] =          {{EVO_LEVEL, 36, SPECIES_SERPERIOR, 0}},
	[SPECIES_TEPIG] =            {{EVO_LEVEL, 17, SPECIES_PIGNITE, 0}},
	[SPECIES_PIGNITE] =          {{EVO_LEVEL, 36, SPECIES_EMBOAR, 0}},
	[SPECIES_OSHAWOTT] =         {{EVO_LEVEL, 17, SPECIES_DEWOTT, 0}},
	[SPECIES_DEWOTT] =           {{EVO_LEVEL, 36, SPECIES_SAMUROTT, 0}},
	[SPECIES_PATRAT] =           {{EVO_LEVEL, 20, SPECIES_WATCHOG, 0}},
	[SPECIES_LILLIPUP] =         {{EVO_LEVEL, 16, SPECIES_HERDIER, 0}},
	[SPECIES_HERDIER] =          {{EVO_LEVEL, 32, SPECIES_STOUTLAND, 0}},
	[SPECIES_PURRLOIN] =         {{EVO_LEVEL, 20, SPECIES_LIEPARD, 0}},
	[SPECIES_PANSAGE] =          {{EVO_ITEM, ITEM_LEAF_STONE, SPECIES_SIMISAGE, 0}},
	[SPECIES_PANSEAR] =          {{EVO_ITEM, ITEM_FIRE_STONE, SPECIES_SIMISEAR, 0}},
	[SPECIES_PANPOUR] =          {{EVO_ITEM, ITEM_WATER_STONE, SPECIES_SIMIPOUR, 0}},
	[SPECIES_MUNNA] =            {{EVO_ITEM, ITEM_MOON_STONE, SPECIES_MUSHARNA, 0}},
	[SPECIES_PIDOVE] =           {{EVO_LEVEL, 21, SPECIES_TRANQUILL, 0}},
	[SPECIES_TRANQUILL] =        {{EVO_LEVEL, 32, SPECIES_UNFEZANT, 0}},
	[SPECIES_BLITZLE] =          {{EVO_LEVEL, 27, SPECIES_ZEBSTRIKA, 0}},
	[SPECIES_ROGGENROLA] =       {{EVO_LEVEL, 25, SPECIES_BOLDORE, 0}},
	[SPECIES_BOLDORE] =          {{EVO_ITEM, ITEM_LINK_CABLE, SPECIES_GIGALITH, 0},
								  {EVO_TRADE, 0, SPECIES_GIGALITH, 0}},
	[SPECIES_WOOBAT] =           {{EVO_FRIENDSHIP, 0, SPECIES_SWOOBAT, 0}},
	[SPECIES_DRILBUR] =          {{EVO_LEVEL, 31, SPECIES_EXCADRILL, 0}},
	[SPECIES_AUDINO] =           {{EVO_MEGA, ITEM_AUDINITE, SPECIES_AUDINO_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_TIMBURR] =          {{EVO_LEVEL, 25, SPECIES_GURDURR, 0}},
	[SPECIES_GURDURR] =          {{EVO_TRADE, 0, SPECIES_CONKELDURR, 0},
								  {EVO_ITEM, ITEM_LINK_CABLE, SPECIES_CONKELDURR, 0}},
	[SPECIES_TYMPOLE] =          {{EVO_LEVEL, 25, SPECIES_PALPITOAD, 0}},
	[SPECIES_PALPITOAD] =        {{EVO_LEVEL, 36, SPECIES_SEISMITOAD, 0}},
	[SPECIES_SEWADDLE] =         {{EVO_LEVEL, 20, SPECIES_SWADLOON, 0}},
	[SPECIES_SWADLOON] =         {{EVO_FRIENDSHIP, 0, SPECIES_LEAVANNY, 0}},
	[SPECIES_VENIPEDE] =         {{EVO_LEVEL, 22, SPECIES_WHIRLIPEDE, 0}},
	[SPECIES_WHIRLIPEDE] =       {{EVO_LEVEL, 30, SPECIES_SCOLIPEDE, 0}},
	[SPECIES_COTTONEE] =         {{EVO_ITEM, ITEM_SUN_STONE, SPECIES_WHIMSICOTT, 0}},
	[SPECIES_PETILIL] =          {{EVO_ITEM, ITEM_SUN_STONE, SPECIES_LILLIGANT, 0}},
	[SPECIES_SANDILE] =          {{EVO_LEVEL, 29, SPECIES_KROKOROK, 0}},
	[SPECIES_KROKOROK] =         {{EVO_LEVEL, 40, SPECIES_KROOKODILE, 0}},
	[SPECIES_DARUMAKA] =         {{EVO_LEVEL, 35, SPECIES_DARMANITAN, 0}},
	[SPECIES_DWEBBLE] =          {{EVO_LEVEL, 34, SPECIES_CRUSTLE, 0}},
	[SPECIES_SCRAGGY] =          {{EVO_LEVEL, 39, SPECIES_SCRAFTY, 0}},
	[SPECIES_YAMASK] =           {{EVO_LEVEL, 34, SPECIES_COFAGRIGUS, 0}},
	[SPECIES_TIRTOUGA] =         {{EVO_LEVEL, 37, SPECIES_CARRACOSTA, 0}},
	[SPECIES_ARCHEN] =           {{EVO_LEVEL, 37, SPECIES_ARCHEOPS, 0}},
	[SPECIES_TRUBBISH] =         {{EVO_LEVEL, 36, SPECIES_GARBODOR, 0}},
	[SPECIES_ZORUA] =            {{EVO_LEVEL, 30, SPECIES_ZOROARK, 0}},
	[SPECIES_MINCCINO] =         {{EVO_ITEM, ITEM_SHINY_STONE, SPECIES_CINCCINO, 0}},
	[SPECIES_GOTHITA] =          {{EVO_LEVEL, 32, SPECIES_GOTHORITA, 0}},
	[SPECIES_GOTHORITA] =        {{EVO_LEVEL, 41, SPECIES_GOTHITELLE, 0}},
	[SPECIES_SOLOSIS] =          {{EVO_LEVEL, 32, SPECIES_DUOSION, 0}},
	[SPECIES_DUOSION] =          {{EVO_LEVEL, 41, SPECIES_REUNICLUS, 0}},
	[SPECIES_DUCKLETT] =         {{EVO_LEVEL, 35, SPECIES_SWANNA, 0}},
	[SPECIES_VANILLITE] =        {{EVO_LEVEL, 35, SPECIES_VANILLISH, 0}},
	[SPECIES_VANILLISH] =        {{EVO_LEVEL, 47, SPECIES_VANILLUXE, 0}},
	[SPECIES_DEERLING] =         {{EVO_LEVEL, 34, SPECIES_SAWSBUCK, 0}},
	[SPECIES_KARRABLAST] =       {{EVO_ITEM, ITEM_LINK_CABLE, SPECIES_ESCAVALIER, 0},
								  {EVO_TRADE, 0, SPECIES_ESCAVALIER, 0}},
	[SPECIES_FOONGUS] =          {{EVO_LEVEL, 39, SPECIES_AMOONGUSS, 0}},
	[SPECIES_FRILLISH] =         {{EVO_LEVEL, 40, SPECIES_JELLICENT, 0}},
	[SPECIES_JOLTIK] =           {{EVO_LEVEL, 36, SPECIES_GALVANTULA, 0}},
	[SPECIES_FERROSEED] =        {{EVO_LEVEL, 40, SPECIES_FERROTHORN, 0}},
	[SPECIES_KLINK] =            {{EVO_LEVEL, 38, SPECIES_KLANG, 0}},
	[SPECIES_KLANG] =            {{EVO_LEVEL, 49, SPECIES_KLINKLANG, 0}},
	[SPECIES_TYNAMO] =           {{EVO_LEVEL, 39, SPECIES_EELEKTRIK, 0}},
	[SPECIES_EELEKTRIK] =        {{EVO_ITEM, ITEM_THUNDER_STONE, SPECIES_EELEKTROSS, 0}},
	[SPECIES_ELGYEM] =           {{EVO_LEVEL, 42, SPECIES_BEHEEYEM, 0}},
	[SPECIES_LITWICK] =          {{EVO_LEVEL, 41, SPECIES_LAMPENT, 0}},
	[SPECIES_LAMPENT] =          {{EVO_ITEM, ITEM_DUSK_STONE, SPECIES_CHANDELURE, 0}},
	[SPECIES_AXEW] =             {{EVO_LEVEL, 38, SPECIES_FRAXURE, 0}},
	[SPECIES_FRAXURE] =          {{EVO_LEVEL, 48, SPECIES_HAXORUS, 0}},
	[SPECIES_CUBCHOO] =          {{EVO_LEVEL, 37, SPECIES_BEARTIC, 0}},
	[SPECIES_SHELMET] =          {{EVO_ITEM, ITEM_LINK_CABLE, SPECIES_ACCELGOR, 0},
								  {EVO_TRADE, 0, SPECIES_ACCELGOR, 0}},
	[SPECIES_MIENFOO] =          {{EVO_LEVEL, 50, SPECIES_MIENSHAO, 0}},
	[SPECIES_GOLETT] =           {{EVO_LEVEL, 43, SPECIES_GOLURK, 0}},
	[SPECIES_PAWNIARD] =         {{EVO_LEVEL, 52, SPECIES_BISHARP, 0}},
	[SPECIES_RUFFLET] =          {{EVO_LEVEL, 54, SPECIES_BRAVIARY, 0}},
	[SPECIES_VULLABY] =          {{EVO_LEVEL, 54, SPECIES_MANDIBUZZ, 0}},
	[SPECIES_DEINO] =            {{EVO_LEVEL, 50, SPECIES_ZWEILOUS, 0}},
	[SPECIES_ZWEILOUS] =         {{EVO_LEVEL, 64, SPECIES_HYDREIGON, 0}},
	[SPECIES_LARVESTA] =         {{EVO_LEVEL, 59, SPECIES_VOLCARONA, 0}},
	[SPECIES_FRILLISH_F] =       {{EVO_LEVEL, 40, SPECIES_JELLICENT_F, 0}}, //Don't use this! It's just meant to be used as a sprite placeholder
	[SPECIES_BURMY_SANDY] =      {{EVO_FEMALE_LEVEL, 20, SPECIES_WORMADAM_SANDY, 0},
								  {EVO_MALE_LEVEL, 20, SPECIES_MOTHIM, 0}},
	[SPECIES_BURMY_TRASH] =      {{EVO_FEMALE_LEVEL, 20, SPECIES_WORMADAM_TRASH, 0},
								  {EVO_MALE_LEVEL, 20, SPECIES_MOTHIM, 0}},
	[SPECIES_SHELLOS_EAST] =     {{EVO_LEVEL, 30, SPECIES_GASTRODON_EAST, 0}},
	[SPECIES_DEERLING_SUMMER] =  {{EVO_LEVEL, 34, SPECIES_SAWSBUCK_SUMMER, 0}},
	[SPECIES_DEERLING_AUTUMN] =  {{EVO_LEVEL, 34, SPECIES_SAWSBUCK_AUTUMN, 0}},
	[SPECIES_DEERLING_WINTER] =  {{EVO_LEVEL, 34, SPECIES_SAWSBUCK_WINTER, 0}},
	[SPECIES_HIPPOPOTAS_F] =     {{EVO_LEVEL, 34, SPECIES_HIPPOWDON_F, 0}}, //Don't use this! It's just meant to be used as a sprite placeholder
	[SPECIES_CHESPIN] =          {{EVO_LEVEL, 16, SPECIES_QUILLADIN, 0}},
	[SPECIES_QUILLADIN] =        {{EVO_LEVEL, 36, SPECIES_CHESNAUGHT, 0}},
	[SPECIES_FENNEKIN] =         {{EVO_LEVEL, 16, SPECIES_BRAIXEN, 0}},
	[SPECIES_BRAIXEN] =          {{EVO_LEVEL, 36, SPECIES_DELPHOX, 0}},
	[SPECIES_FROAKIE] =          {{EVO_LEVEL, 16, SPECIES_FROGADIER, 0}},
	[SPECIES_FROGADIER] =        {{EVO_LEVEL, 36, SPECIES_GRENINJA, 0}},
	[SPECIES_BUNNELBY] =         {{EVO_LEVEL, 20, SPECIES_DIGGERSBY, 0}},
	[SPECIES_FLETCHLING] =       {{EVO_LEVEL, 17, SPECIES_FLETCHINDER, 0}},
	[SPECIES_FLETCHINDER] =      {{EVO_LEVEL, 35, SPECIES_TALONFLAME, 0}},
	[SPECIES_SCATTERBUG] =       {{EVO_LEVEL, 9, SPECIES_SPEWPA, 0}},
	[SPECIES_SPEWPA] =           {{EVO_LEVEL, 12, SPECIES_VIVILLON, 0}},
	[SPECIES_LITLEO] =           {{EVO_LEVEL, 35, SPECIES_PYROAR, 0}},
	[SPECIES_FLABEBE] =          {{EVO_LEVEL, 19, SPECIES_FLOETTE, 0}},
	[SPECIES_FLOETTE] =          {{EVO_ITEM, ITEM_SHINY_STONE, SPECIES_FLORGES, 0}},
	[SPECIES_SKIDDO] =           {{EVO_LEVEL, 32, SPECIES_GOGOAT, 0}},
	[SPECIES_PANCHAM] =          {{EVO_TYPE_IN_PARTY, 32, SPECIES_PANGORO, TYPE_DARK}},
	[SPECIES_ESPURR] =           {{EVO_MALE_LEVEL, 25, SPECIES_MEOWSTIC, 0},
								  {EVO_FEMALE_LEVEL, 25, SPECIES_MEOWSTIC_FEMALE, 0}},
	[SPECIES_HONEDGE] =          {{EVO_LEVEL, 35, SPECIES_DOUBLADE, 0}},
	[SPECIES_DOUBLADE] =         {{EVO_ITEM, ITEM_DUSK_STONE, SPECIES_AEGISLASH, 0}},
	[SPECIES_SPRITZEE] =         {{EVO_ITEM, ITEM_SACHET, SPECIES_AROMATISSE, 0},
								  {EVO_TRADE_ITEM, ITEM_SACHET, SPECIES_AROMATISSE, 0}},
	[SPECIES_SWIRLIX] =          {{EVO_ITEM, ITEM_WHIPPED_DREAM, SPECIES_SLURPUFF, 0},
								  {EVO_TRADE_ITEM, ITEM_WHIPPED_DREAM, SPECIES_SLURPUFF, 0}},
	[SPECIES_INKAY] =            {{EVO_LEVEL, 30, SPECIES_MALAMAR, 0}},
	[SPECIES_BINACLE] =          {{EVO_LEVEL, 39, SPECIES_BARBARACLE, 0}},
	[SPECIES_SKRELP] =           {{EVO_LEVEL, 48, SPECIES_DRAGALGE, 0}},
	[SPECIES_CLAUNCHER] =        {{EVO_LEVEL, 37, SPECIES_CLAWITZER, 0}},
	[SPECIES_HELIOPTILE] =       {{EVO_ITEM, ITEM_SUN_STONE, SPECIES_HELIOLISK, 0}},
	[SPECIES_TYRUNT] =           {{EVO_LEVEL_DAY, 39, SPECIES_TYRANTRUM, 0}},
	[SPECIES_AMAURA] =           {{EVO_LEVEL_NIGHT, 39, SPECIES_AURORUS, 0}},
	[SPECIES_GOOMY] =            {{EVO_LEVEL, 40, SPECIES_SLIGGOO, 0}},
	[SPECIES_SLIGGOO] =          {{EVO_RAINY_FOGGY_OW, 50, SPECIES_GOODRA, 0}},
	[SPECIES_PHANTUMP] =         {{EVO_TRADE, 0, SPECIES_TREVENANT, 0},
								  {EVO_ITEM, ITEM_LINK_CABLE, SPECIES_TREVENANT, 0}},
	[SPECIES_PUMPKABOO] =        {{EVO_TRADE, 0, SPECIES_GOURGEIST, 0},
								  {EVO_ITEM, ITEM_LINK_CABLE, SPECIES_GOURGEIST, 0}},
	[SPECIES_BERGMITE] =         {{EVO_LEVEL, 37, SPECIES_AVALUGG, 0}},
	[SPECIES_NOIBAT] =           {{EVO_LEVEL, 48, SPECIES_NOIVERN, 0}},
	[SPECIES_DIANCIE] =          {{EVO_MEGA, ITEM_DIANCITE, SPECIES_DIANCIE_MEGA, MEGA_VARIANT_STANDARD}},
	[SPECIES_FLABEBE_BLUE] =     {{EVO_LEVEL, 19, SPECIES_FLOETTE_BLUE, 0}},
	[SPECIES_FLABEBE_ORANGE] =   {{EVO_LEVEL, 19, SPECIES_FLOETTE_ORANGE, 0}},
	[SPECIES_FLABEBE_YELLOW] =   {{EVO_LEVEL, 19, SPECIES_FLOETTE_YELLOW, 0}},
	[SPECIES_FLABEBE_WHITE] =    {{EVO_LEVEL, 19, SPECIES_FLOETTE_WHITE, 0}},
	[SPECIES_FLOETTE_BLUE] =     {{EVO_ITEM, ITEM_SHINY_STONE, SPECIES_FLORGES_BLUE, 0}},
	[SPECIES_FLOETTE_ORANGE] =   {{EVO_ITEM, ITEM_SHINY_STONE, SPECIES_FLORGES_ORANGE, 0}},
	[SPECIES_FLOETTE_YELLOW] =   {{EVO_ITEM, ITEM_SHINY_STONE, SPECIES_FLORGES_YELLOW, 0}},
	[SPECIES_FLOETTE_WHITE] =    {{EVO_ITEM, ITEM_SHINY_STONE, SPECIES_FLORGES_WHITE, 0}},
	[SPECIES_PUMPKABOO_XL] =     {{EVO_TRADE, 0, SPECIES_GOURGEIST_XL, 0},
								  {EVO_ITEM, ITEM_LINK_CABLE, SPECIES_GOURGEIST_XL, 0}},
	[SPECIES_PUMPKABOO_L] =      {{EVO_TRADE, 0, SPECIES_GOURGEIST_L, 0},
								  {EVO_ITEM, ITEM_LINK_CABLE, SPECIES_GOURGEIST_L, 0}},
	[SPECIES_PUMPKABOO_M] =      {{EVO_TRADE, 0, SPECIES_GOURGEIST_M, 0},
								  {EVO_ITEM, ITEM_LINK_CABLE, SPECIES_GOURGEIST_M, 0}},
	[SPECIES_VENUSAUR_MEGA] =    {{EVO_MEGA, ITEM_NONE, SPECIES_VENUSAUR, MEGA_VARIANT_STANDARD}},
	[SPECIES_CHARIZARD_MEGA_X] = {{EVO_MEGA, ITEM_NONE, SPECIES_CHARIZARD, MEGA_VARIANT_STANDARD}},
	[SPECIES_CHARIZARD_MEGA_Y] = {{EVO_MEGA, ITEM_NONE, SPECIES_CHARIZARD, MEGA_VARIANT_STANDARD}},
	[SPECIES_BLASTOISE_MEGA] =   {{EVO_MEGA, ITEM_NONE, SPECIES_BLASTOISE, MEGA_VARIANT_STANDARD}},
	[SPECIES_BEEDRILL_MEGA] =    {{EVO_MEGA, ITEM_NONE, SPECIES_BEEDRILL, MEGA_VARIANT_STANDARD}},
	[SPECIES_PIDGEOT_MEGA] =     {{EVO_MEGA, ITEM_NONE, SPECIES_PIDGEOT, MEGA_VARIANT_STANDARD}},
	[SPECIES_ALAKAZAM_MEGA] =    {{EVO_MEGA, ITEM_NONE, SPECIES_ALAKAZAM, MEGA_VARIANT_STANDARD}},
	[SPECIES_SLOWBRO_MEGA] =     {{EVO_MEGA, ITEM_NONE, SPECIES_SLOWBRO, MEGA_VARIANT_STANDARD}},
	[SPECIES_GENGAR_MEGA] =      {{EVO_MEGA, ITEM_NONE, SPECIES_GENGAR, MEGA_VARIANT_STANDARD}},
	[SPECIES_KANGASKHAN_MEGA] =  {{EVO_MEGA, ITEM_NONE, SPECIES_KANGASKHAN, MEGA_VARIANT_STANDARD}},
	[SPECIES_PINSIR_MEGA] =      {{EVO_MEGA, ITEM_NONE, SPECIES_PINSIR, MEGA_VARIANT_STANDARD}},
	[SPECIES_GYARADOS_MEGA] =    {{EVO_MEGA, ITEM_NONE, SPECIES_GYARADOS, MEGA_VARIANT_STANDARD}},
	[SPECIES_AERODACTYL_MEGA] =  {{EVO_MEGA, ITEM_NONE, SPECIES_AERODACTYL, MEGA_VARIANT_STANDARD}},
	[SPECIES_MEWTWO_MEGA_X] =    {{EVO_MEGA, ITEM_NONE, SPECIES_MEWTWO, MEGA_VARIANT_STANDARD}},
	[SPECIES_MEWTWO_MEGA_Y] =    {{EVO_MEGA, ITEM_NONE, SPECIES_MEWTWO, MEGA_VARIANT_STANDARD}},
	[SPECIES_AMPHAROS_MEGA] =    {{EVO_MEGA, ITEM_NONE, SPECIES_AMPHAROS, MEGA_VARIANT_STANDARD}},
	[SPECIES_STEELIX_MEGA] =     {{EVO_MEGA, ITEM_NONE, SPECIES_STEELIX, MEGA_VARIANT_STANDARD}},
	[SPECIES_SCIZOR_MEGA] =      {{EVO_MEGA, ITEM_NONE, SPECIES_SCIZOR, MEGA_VARIANT_STANDARD}},
	[SPECIES_HERACROSS_MEGA] =   {{EVO_MEGA, ITEM_NONE, SPECIES_HERACROSS, MEGA_VARIANT_STANDARD}},
	[SPECIES_HOUNDOOM_MEGA] =    {{EVO_MEGA, ITEM_NONE, SPECIES_HOUNDOOM, MEGA_VARIANT_STANDARD}},
	[SPECIES_TYRANITAR_MEGA] =   {{EVO_MEGA, ITEM_NONE, SPECIES_TYRANITAR, MEGA_VARIANT_STANDARD}},
	[SPECIES_SCEPTILE_MEGA] =    {{EVO_MEGA, ITEM_NONE, SPECIES_SCEPTILE, MEGA_VARIANT_STANDARD}},
	[SPECIES_BLAZIKEN_MEGA] =    {{EVO_MEGA, ITEM_NONE, SPECIES_BLAZIKEN, MEGA_VARIANT_STANDARD}},
	[SPECIES_SWAMPERT_MEGA] =    {{EVO_MEGA, ITEM_NONE, SPECIES_SWAMPERT, MEGA_VARIANT_STANDARD}},
	[SPECIES_GARDEVOIR_MEGA] =   {{EVO_MEGA, ITEM_NONE, SPECIES_GARDEVOIR, MEGA_VARIANT_STANDARD}},
	[SPECIES_SABLEYE_MEGA] =     {{EVO_MEGA, ITEM_NONE, SPECIES_SABLEYE, MEGA_VARIANT_STANDARD}},
	[SPECIES_MAWILE_MEGA] =      {{EVO_MEGA, ITEM_NONE, SPECIES_MAWILE, MEGA_VARIANT_STANDARD}},
	[SPECIES_AGGRON_MEGA] =      {{EVO_MEGA, ITEM_NONE, SPECIES_AGGRON, MEGA_VARIANT_STANDARD}},
	[SPECIES_MEDICHAM_MEGA] =    {{EVO_MEGA, ITEM_NONE, SPECIES_MEDICHAM, MEGA_VARIANT_STANDARD}},
	[SPECIES_MANECTRIC_MEGA] =   {{EVO_MEGA, ITEM_NONE, SPECIES_MANECTRIC, MEGA_VARIANT_STANDARD}},
	[SPECIES_SHARPEDO_MEGA] =    {{EVO_MEGA, ITEM_NONE, SPECIES_SHARPEDO, MEGA_VARIANT_STANDARD}},
	[SPECIES_CAMERUPT_MEGA] =    {{EVO_MEGA, ITEM_NONE, SPECIES_CAMERUPT, MEGA_VARIANT_STANDARD}},
	[SPECIES_ALTARIA_MEGA] =     {{EVO_MEGA, ITEM_NONE, SPECIES_ALTARIA, MEGA_VARIANT_STANDARD}},
	[SPECIES_BANETTE_MEGA] =     {{EVO_MEGA, ITEM_NONE, SPECIES_BANETTE, MEGA_VARIANT_STANDARD}},
	[SPECIES_ABSOL_MEGA] =       {{EVO_MEGA, ITEM_NONE, SPECIES_ABSOL, MEGA_VARIANT_STANDARD}},
	[SPECIES_GLALIE_MEGA] =      {{EVO_MEGA, ITEM_NONE, SPECIES_GLALIE, MEGA_VARIANT_STANDARD}},
	[SPECIES_SALAMENCE_MEGA] =   {{EVO_MEGA, ITEM_NONE, SPECIES_SALAMENCE, MEGA_VARIANT_STANDARD}},
	[SPECIES_METAGROSS_MEGA] =   {{EVO_MEGA, ITEM_NONE, SPECIES_METAGROSS, MEGA_VARIANT_STANDARD}},
	[SPECIES_LATIAS_MEGA] =      {{EVO_MEGA, ITEM_NONE, SPECIES_LATIAS, MEGA_VARIANT_STANDARD}},
	[SPECIES_LATIOS_MEGA] =      {{EVO_MEGA, ITEM_NONE, SPECIES_LATIOS, MEGA_VARIANT_STANDARD}},
	[SPECIES_GROUDON_PRIMAL] =   {{EVO_MEGA, ITEM_NONE, SPECIES_GROUDON, MEGA_VARIANT_PRIMAL}},
	[SPECIES_KYOGRE_PRIMAL] =    {{EVO_MEGA, ITEM_NONE, SPECIES_KYOGRE, MEGA_VARIANT_PRIMAL}},
	[SPECIES_RAYQUAZA_MEGA] =    {{EVO_MEGA, MOVE_NONE, SPECIES_RAYQUAZA, MEGA_VARIANT_WISH}},
	[SPECIES_LOPUNNY_MEGA] =     {{EVO_MEGA, ITEM_NONE, SPECIES_LOPUNNY, MEGA_VARIANT_STANDARD}},
	[SPECIES_GARCHOMP_MEGA] =    {{EVO_MEGA, ITEM_NONE, SPECIES_GARCHOMP, MEGA_VARIANT_STANDARD}},
	[SPECIES_LUCARIO_MEGA] =     {{EVO_MEGA, ITEM_NONE, SPECIES_LUCARIO, MEGA_VARIANT_STANDARD}},
	[SPECIES_ABOMASNOW_MEGA] =   {{EVO_MEGA, ITEM_NONE, SPECIES_ABOMASNOW, MEGA_VARIANT_STANDARD}},
	[SPECIES_GALLADE_MEGA] =     {{EVO_MEGA, ITEM_NONE, SPECIES_GALLADE, MEGA_VARIANT_STANDARD}},
	[SPECIES_AUDINO_MEGA] =      {{EVO_MEGA, ITEM_NONE, SPECIES_AUDINO, MEGA_VARIANT_STANDARD}},
	[SPECIES_DIANCIE_MEGA] =     {{EVO_MEGA, ITEM_NONE, SPECIES_DIANCIE, MEGA_VARIANT_STANDARD}},
	[SPECIES_ROWLET] =           {{EVO_LEVEL, 17, SPECIES_DARTRIX, 0}},
	[SPECIES_DARTRIX] =          {{EVO_LEVEL, 34, SPECIES_DECIDUEYE, 0}},
	[SPECIES_LITTEN] =           {{EVO_LEVEL, 17, SPECIES_TORRACAT, 0}},
	[SPECIES_TORRACAT] =         {{EVO_LEVEL, 34, SPECIES_INCINEROAR, 0}},
	[SPECIES_POPPLIO] =          {{EVO_LEVEL, 17, SPECIES_BRIONNE, 0}},
	[SPECIES_BRIONNE] =          {{EVO_LEVEL, 34, SPECIES_PRIMARINA, 0}},
	[SPECIES_PIKIPEK] =          {{EVO_LEVEL, 14, SPECIES_TRUMBEAK, 0}},
	[SPECIES_TRUMBEAK] =         {{EVO_LEVEL, 28, SPECIES_TOUCANNON, 0}},
	[SPECIES_YUNGOOS] =          {{EVO_LEVEL_DAY, 20, SPECIES_GUMSHOOS, 0}},
	[SPECIES_GRUBBIN] =          {{EVO_LEVEL, 20, SPECIES_CHARJABUG, 0}},
	[SPECIES_CHARJABUG] =        {{EVO_ITEM, ITEM_THUNDER_STONE, SPECIES_VIKAVOLT, 0}},
	[SPECIES_CRABRAWLER] =       {{EVO_ITEM, ITEM_ICE_STONE, SPECIES_CRABOMINABLE, 0}},
	[SPECIES_CUTIEFLY] =         {{EVO_LEVEL, 25, SPECIES_RIBOMBEE, 0}},
	[SPECIES_ROCKRUFF] =         {{EVO_LEVEL_DAY, 25, SPECIES_LYCANROC, 0},
								  {EVO_LEVEL_NIGHT, 25, SPECIES_LYCANROC_N, 0},
								  {EVO_LEVEL_SPECIFIC_TIME_RANGE, 25, SPECIES_LYCANROC_DUSK, TIME_RANGE(17, 20)}}, //5 PM - 7:59 PM 
	[SPECIES_MAREANIE] =         {{EVO_LEVEL, 38, SPECIES_TOXAPEX, 0}},
	[SPECIES_MUDBRAY] =          {{EVO_LEVEL, 30, SPECIES_MUDSDALE, 0}},
	[SPECIES_DEWPIDER] =         {{EVO_LEVEL, 22, SPECIES_ARAQUANID, 0}},
	[SPECIES_FOMANTIS] =         {{EVO_LEVEL_DAY, 34, SPECIES_LURANTIS, 0}},
	[SPECIES_MORELULL] =         {{EVO_LEVEL, 24, SPECIES_SHIINOTIC, 0}},
	[SPECIES_SALANDIT] =         {{EVO_LEVEL, 33, SPECIES_SALAZZLE, 0}},
	[SPECIES_STUFFUL] =          {{EVO_LEVEL, 27, SPECIES_BEWEAR, 0}},
	[SPECIES_BOUNSWEET] =        {{EVO_LEVEL, 18, SPECIES_STEENEE, 0}},
	[SPECIES_STEENEE] =          {{EVO_MOVE, MOVE_STOMP, SPECIES_TSAREENA, 0}},
	[SPECIES_WIMPOD] =           {{EVO_LEVEL, 30, SPECIES_GOLISOPOD, 0}},
	[SPECIES_SANDYGAST] =        {{EVO_LEVEL, 42, SPECIES_PALOSSAND, 0}},
	[SPECIES_TYPE_NULL] =        {{EVO_FRIENDSHIP, 0, SPECIES_SILVALLY, 0}},
	[SPECIES_JANGMO_O] =         {{EVO_LEVEL, 35, SPECIES_HAKAMO_O, 0}},
	[SPECIES_HAKAMO_O] =         {{EVO_LEVEL, 45, SPECIES_KOMMO_O, 0}},
	[SPECIES_COSMOG] =           {{EVO_LEVEL, 43, SPECIES_COSMOEM, 0}},
	[SPECIES_COSMOEM] =          {{EVO_LEVEL_DAY, 53, SPECIES_SOLGALEO, 0},
								  {EVO_LEVEL_NIGHT, 53, SPECIES_LUNALA, 0}},
	[SPECIES_RATTATA_A] =        {{EVO_LEVEL_NIGHT, 20, SPECIES_RATICATE_A, 0}},
	[SPECIES_SANDSHREW_A] =      {{EVO_ITEM, ITEM_ICE_STONE, SPECIES_SANDSLASH_A, 0}},
	[SPECIES_VULPIX_A] =         {{EVO_ITEM, ITEM_ICE_STONE, SPECIES_NINETALES_A, 0}},
	[SPECIES_DIGLETT_A] =        {{EVO_LEVEL, 26, SPECIES_DUGTRIO_A, 0}},
	[SPECIES_MEOWTH_A] =         {{EVO_FRIENDSHIP, 0, SPECIES_PERSIAN_A, 0}},
	[SPECIES_GEODUDE_A] =        {{EVO_LEVEL, 25, SPECIES_GRAVELER_A, 0}},
	[SPECIES_GRAVELER_A] =       {{EVO_ITEM, ITEM_LINK_CABLE, SPECIES_GOLEM_A, 0},
								  {EVO_TRADE, 0, SPECIES_GOLEM_A, 0}},
	[SPECIES_GRIMER_A] =         {{EVO_LEVEL, 38, SPECIES_MUK_A, 0}},
	[SPECIES_EXEGGCUTE_A] =      {{EVO_ITEM, ITEM_LEAF_STONE, SPECIES_EXEGGUTOR_A, 0}},
	[SPECIES_CUBONE_A] =         {{EVO_LEVEL_NIGHT, 28, SPECIES_MAROWAK_A, 0}},
	[SPECIES_POIPOLE] =          {{EVO_MOVE, MOVE_DRAGONPULSE, SPECIES_NAGANADEL, 0}},
	[SPECIES_NECROZMA_DUSK_MANE] =  {{EVO_MEGA, ITEM_ULTRANECROZIUM_Z, SPECIES_NECROZMA_ULTRA, MEGA_VARIANT_ULTRA_BURST}},
	[SPECIES_NECROZMA_DAWN_WINGS] = {{EVO_MEGA, ITEM_ULTRANECROZIUM_Z, SPECIES_NECROZMA_ULTRA, MEGA_VARIANT_ULTRA_BURST}},
	[SPECIES_NECROZMA_ULTRA] =   {{EVO_MEGA, ITEM_NONE, SPECIES_NECROZMA_DUSK_MANE, MEGA_VARIANT_ULTRA_BURST},
								  {EVO_MEGA, ITEM_NONE, SPECIES_NECROZMA_DAWN_WINGS, MEGA_VARIANT_ULTRA_BURST}},
	[SPECIES_MELTAN] =	         {{EVO_ITEM, ITEM_METAL_COAT, SPECIES_MELMETAL, 0}},
	[SPECIES_GROOKEY] =          {{EVO_LEVEL, 16, SPECIES_THWACKEY, 0}},
	[SPECIES_THWACKEY] =         {{EVO_LEVEL, 35, SPECIES_RILLABOOM, 0}},
	[SPECIES_SCORBUNNY] =        {{EVO_LEVEL, 16, SPECIES_RABOOT, 0}},
	[SPECIES_RABOOT] =           {{EVO_LEVEL, 35, SPECIES_CINDERACE, 0}}, 
	[SPECIES_SOBBLE] =           {{EVO_LEVEL, 16, SPECIES_DRIZZILE, 0}},
	[SPECIES_DRIZZILE] =         {{EVO_LEVEL, 35, SPECIES_INTELEON, 0}},
	[SPECIES_SKWOVET] =          {{EVO_LEVEL, 24, SPECIES_GREEDENT, 0}},
	[SPECIES_ROOKIDEE] =         {{EVO_LEVEL, 18, SPECIES_CORVISQUIRE, 0}},
	[SPECIES_CORVISQUIRE] =      {{EVO_LEVEL, 38, SPECIES_CORVIKNIGHT, 0}},
	[SPECIES_BLIPBUG] =          {{EVO_LEVEL, 10, SPECIES_DOTTLER, 0}},
	[SPECIES_DOTTLER] =          {{EVO_LEVEL, 30, SPECIES_ORBEETLE, 0}},
	[SPECIES_NICKIT] =           {{EVO_LEVEL, 18, SPECIES_THIEVUL, 0}},
	[SPECIES_GOSSIFLEUR] =       {{EVO_LEVEL, 20, SPECIES_ELDEGOSS, 0}},
	[SPECIES_WOOLOO] =           {{EVO_LEVEL, 24, SPECIES_DUBWOOL, 0}},
	[SPECIES_CHEWTLE] =          {{EVO_LEVEL, 22, SPECIES_DREDNAW, 0}},
	[SPECIES_YAMPER] =           {{EVO_LEVEL, 25, SPECIES_BOLTUND, 0}},
	[SPECIES_ROLYCOLY] =         {{EVO_LEVEL, 18, SPECIES_CARKOL, 0}},
	[SPECIES_CARKOL] =           {{EVO_LEVEL, 34, SPECIES_COALOSSAL, 0}},
	[SPECIES_APPLIN] =           {{EVO_ITEM, ITEM_TART_APPLE, SPECIES_FLAPPLE, 0},
								  {EVO_ITEM, ITEM_SWEET_APPLE, SPECIES_APPLETUN, 0}},
	[SPECIES_SILICOBRA] =        {{EVO_LEVEL, 36, SPECIES_SANDACONDA, 0}},
	[SPECIES_ARROKUDA] =         {{EVO_LEVEL, 26, SPECIES_BARRASKEWDA, 0}},
	[SPECIES_TOXEL] =            {{EVO_LEVEL_SILCOON, 30, SPECIES_TOXTRICITY, 0},
								  {EVO_LEVEL_CASCOON, 30, SPECIES_TOXTRICITY_LOW_KEY, 0}},
	[SPECIES_SIZZLIPEDE] =       {{EVO_LEVEL, 28, SPECIES_CENTISKORCH, 0}},
	[SPECIES_CLOBBOPUS] =        {{EVO_MOVE, MOVE_TAUNT, SPECIES_GRAPPLOCT, 0}},
	[SPECIES_SINISTEA] =         {{EVO_ITEM, ITEM_CRACKED_POT, SPECIES_POLTEAGEIST, 0}},
	[SPECIES_HATENNA] =          {{EVO_LEVEL, 32, SPECIES_HATTREM, 0}},
	[SPECIES_HATTREM] =          {{EVO_LEVEL, 42, SPECIES_HATTERENE, 0}},
	[SPECIES_IMPIDIMP] =         {{EVO_LEVEL, 32, SPECIES_MORGREM, 0}},
	[SPECIES_MORGREM] =          {{EVO_LEVEL, 42, SPECIES_GRIMMSNARL, 0}},
	[SPECIES_MILCERY] =          {{EVO_ITEM, ITEM_STRAWBERRY_SWEET, SPECIES_ALCREMIE_STRAWBERRY, 0},
								{EVO_ITEM, ITEM_BERRY_SWEET, SPECIES_ALCREMIE_BERRY, 0},
					       			{EVO_ITEM, ITEM_LOVE_SWEET, SPECIES_ALCREMIE_LOVE, 0},
								{EVO_ITEM, ITEM_CLOVER_SWEET, SPECIES_ALCREMIE_CLOVER, 0},
								{EVO_ITEM, ITEM_FLOWER_SWEET, SPECIES_ALCREMIE_FLOWER, 0},
					  			{EVO_ITEM, ITEM_RIBBON_SWEET, SPECIES_ALCREMIE_RIBBON, 0},
					   			{EVO_ITEM, ITEM_STAR_SWEET, SPECIES_ALCREMIE_STAR, 0}},
	[SPECIES_SNOM] =             {{EVO_FRIENDSHIP_NIGHT, 0, SPECIES_FROSMOTH, 0}},
	[SPECIES_CUFANT] =           {{EVO_LEVEL, 34, SPECIES_COPPERAJAH, 0}},
	[SPECIES_DREEPY] =           {{EVO_LEVEL, 50, SPECIES_DRAKLOAK, 0}},
	[SPECIES_DRAKLOAK] =         {{EVO_LEVEL, 60, SPECIES_DRAGAPULT, 0}},
	[SPECIES_KUBFU] =            {{EVO_MOVE_TYPE, TYPE_DARK, SPECIES_URSHIFU_SINGLE, 0},
								  {EVO_MOVE_TYPE, TYPE_WATER, SPECIES_URSHIFU_RAPID, 0}}, //Location/event based evolution
};